pub fn init(stdout: &'static dyn StdOut) -> Result<(), SetStdoutError>Expand description
Initialized the global stdout with the a specified &'static dyn StdOut.
This function may only be called once during the program lifecycle.
pub fn init(stdout: &'static dyn StdOut) -> Result<(), SetStdoutError>Initialized the global stdout with the a specified &'static dyn StdOut.
This function may only be called once during the program lifecycle.